package com.ruoyi.ss.channel.service;

import com.ruoyi.ss.channel.domain.ChannelQuery;
import com.ruoyi.ss.channel.domain.Channel;
import com.ruoyi.ss.channel.domain.ChannelVO;

import java.util.List;
import java.util.Map;
import java.util.function.Function;

/**
 * 充值渠道Service接口
 *
 * @author ruoyi
 * @date 2024-04-15
 */
public interface IChannelService
{
    /**
     * 查询充值渠道
     *
     * @param channelId 充值渠道主键
     * @return 充值渠道
     */
    public ChannelVO selectChannelByChannelId(Long channelId);

    /**
     * 查询充值渠道列表
     *
     * @param smChannel 充值渠道
     * @return 充值渠道集合
     */
    public List<ChannelVO> selectSmChannelList(ChannelQuery smChannel);

    /**
     * 新增充值渠道
     *
     * @param channel 充值渠道
     * @return 结果
     */
    public int insertSmChannel(Channel channel);

    /**
     * 修改充值渠道
     *
     * @param channel 充值渠道
     * @return 结果
     */
    public int updateSmChannel(Channel channel);

    /**
     * 批量删除充值渠道
     *
     * @param channelIds 需要删除的充值渠道主键集合
     * @return 结果
     */
    public int deleteSmChannelByChannelIds(Long[] channelIds);

    /**
     * 删除充值渠道信息
     *
     * @param channelId 充值渠道主键
     * @return 结果
     */
    public int deleteSmChannelByChannelId(Long channelId);

    /**
     * 查询启用的充值渠道列表
     *
     * @return
     */
    List<ChannelVO> selectEnabledRechargeList();

    /**
     * 查询充值渠道映射表
     *
     * @param query     查询条件
     * @param keyMapper 映射函数
     */
    <K> Map<K, ChannelVO> selectMap(ChannelQuery query, Function<? super Channel, ? extends K> keyMapper);

    /**
     * 根据证书序列号获取支付渠道
     *
     * @param wechatpaySerial 证书序列号
     * @return 结果
     */
    ChannelVO selectChannelBySerialNumber(String wechatpaySerial);

    /**
     * 根据id查询
     */
    List<ChannelVO> selectByIds(List<Long> ids);
}
